#
# spec file for package delayacct-utils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version %(rpm -q --qf '%%{VERSION}' kernel-source)
Name:           delayacct-utils
Version:        %{version}
Release:        32.38
Summary:        Delay Accounting Utilities
License:        GPL-2.0-only
Group:          System/Monitoring
URL:            https://www.kernel.org/
Source0:        delayacct-utils.tar.bz2
Patch0:         delayacct-utils-nl.patch
BuildRequires:  kernel-devel
BuildRequires:  kernel-source

%description
Delay accounting allows the administrator to track the time an
application spends waiting on disk I/O, swap I/O and CPU scheduling.
This can help pin-point resource shortages in a system configuration.

%package rebuild
Summary:        Empty package to ensure rebuilding delayacct-utils in OBS
Group:          System/Monitoring
%requires_eq    kernel-source

%description rebuild
This is empty package that ensures delayacct-utils is rebuilt every time
kernel-default is rebuilt in OBS.

There is no reason to install this package.

%prep
%autosetup -p1 -n %{name}

mkdir -p linux
%if 0%{?suse_version} <= 1220
cp %{_prefix}/src/linux/include/linux/taskstats.h linux/taskstats.h
%else
cp %{_prefix}/src/linux/include/uapi/linux/taskstats.h linux/taskstats.h
%endif
if [ -f %{_prefix}/src/linux/Documentation/accounting/getdelays.c ]; then
	cp %{_prefix}/src/linux/Documentation/accounting/getdelays.c .
fi
if [ -f %{_prefix}/src/linux/tools/accounting/getdelays.c ]; then
	cp %{_prefix}/src/linux/tools/accounting/getdelays.c .
fi

%build
%make_build CCOPT="%{optflags}"

%install
mkdir -p %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1
install -m 555 getdelays %{buildroot}%{_bindir}
install -m 444 getdelays.1 %{buildroot}%{_mandir}/man1

%files
%license COPYING
%doc README
%attr(555,root,root) %{_bindir}/getdelays
%attr(444,root,root) %{_mandir}/man?/*

%files rebuild
%license COPYING

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Apr  8 2022 Dirk Müller <dmueller@suse.com>
- rebuild when kernel version changes
- spec cleaning
* Tue Apr  2 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- BuildRequire kernel-devel because we want to rebuild
  when it gets updated
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Tue Jan 10 2017 meissner@suse.com
- adapt to new kernel version and new location of getdelays.c
* Thu Jun 19 2014 crrodriguez@opensuse.org
- delayacct-utils-nl.patch DO not attempt to link getdelays
  with libnl1, it is a bogus dependency, resulting executable
  never uses the library.
* Sat Jan 26 2013 seife+obs@b1-systems.com
- fix build
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Thu Feb 19 2009 dmueller@suse.de
- drop unnecessary patch, it is now upstream (in the kernel tree)
* Tue Nov 25 2008 meissner@suse.de
- make it not hang if no option is specified bnc#448382
* Thu Jun  5 2008 dmueller@suse.de
- update to kernel 2.6.24.4 (as in openSUSE 11.0) and make
  it generic to always compile against the current kernel sources
* Wed Aug 22 2007 meissner@suse.de
- updated to kernel level 2.6.22 (as in openSUSE 10.3).
* Wed Jul 11 2007 meissner@suse.de
- adjusted getdelays.c to be GPL v2 only, like the
  linux kernel.
* Mon Jan  8 2007 okir@suse.de
- Update getdelays for changed kernel interface
  (#229115, FATE301689, LTC30061)
* Wed May 17 2006 schwab@suse.de
- Don't strip binaries.
* Tue Apr 11 2006 okir@suse.de
- Initial packaging
